// Minecraft Standalone Client
// Copyright (C) 2009-2010 Colin Bartolome
// Licensed under the GPL. See LICENSE.txt for details.

import java.util.*;

import com.mojang.minecraft.l;
import com.mojang.minecraft.level.Level;
import com.mojang.minecraft.player.Player;

public class Compass extends TimerTask
{
   private static final long DELAY = 125;
   
   private static final String FORMAT = "     x: %.1f, y: %.1f, elev: %.1f     tilt: %+d, hdg: %d     tile: %s     %s: %.1f";
   
   private Main main;
   
   private l minecraft;
   
   public Compass(final Main main, final l minecraft)
   {
      this.main = main;
      this.minecraft = minecraft;
      
      new Timer().schedule(this, DELAY, DELAY);
      
      new Timer().schedule(new TimerTask()
      {
         @Override
         public void run()
         {
            Level minecraftLevel;
            Player player;
            
            do
            {
               try
               {
                  Thread.sleep(100);
               }
               catch (InterruptedException ie)
               {
                  System.err.println("Interrupted while waiting for level init.");
               }
               
               minecraftLevel = minecraft.d;
               player = minecraft.f;
            } while (minecraftLevel == null || minecraftLevel.blockMap == null || player == null || player.input == null);
            
            minecraft.f = new CustomPlayer(main, player, minecraftLevel, player.input);
         }
      }, 1000);

      System.out.println("Compass initialized");
   }
   
   @Override
   public void run()
   {
      Player player = minecraft.f;
      
      if (player == null || !(player instanceof CustomPlayer))
         return;
      
      int tilt = -(int)player.xRot;
      int heading = (int)player.yRot % 360;
      CustomPlayer customPlayer = (CustomPlayer)player;
      boolean flying = customPlayer.isFlying();
      float ySpeed = customPlayer.getYSpeed();
      
      if (heading < 0)
         heading += 360;
      
      // player.y is used for elevation, so it makes more sense to me to swap it with player.z
      main.setStatus(String.format(FORMAT, player.x, player.z, player.y - CustomPlayer.PLAYER_HEIGHT, tilt, heading,
         customPlayer.getTileType(), flying ? "flying" : "falling", flying ? ySpeed : player.yd));
   }   
}
