// Minecraft Standalone Client
// Copyright (C) 2009-2010 Colin Bartolome
// Licensed under the GPL. See LICENSE.txt for details.

import javax.swing.SwingUtilities;

import org.lwjgl.input.Keyboard;

import com.mojang.minecraft.level.Level;
import com.mojang.minecraft.player.Player;

public class CustomPlayer extends Player
{
   public static final float PLAYER_HEIGHT = 1.6f;
   
   private static final float MAX_SPEED = 2;
   
   private Main main;
   
   private boolean typing;
   
   private boolean flying;
   
   private float ySpeed;
   
   private boolean keySubtract;
   
   private boolean keyAdd;
   
   private boolean keyFlying;
   
   private boolean keyZero;
   
   private boolean keyTilePlus;
   
   private boolean keyTileMinus;
   
   private boolean keyConjure;
   
   private boolean keyReplace;
   
   private TileType tileType = TileType.DARK_GRAY;
   
   private boolean mapFrameInitialized;
   
   public CustomPlayer(Main main, Player player, final Level level, com.mojang.minecraft.player.a input)
   {
      super(level);
      
      this.main = main;
      this.input = input;
      
      setPos(player.x, player.y, player.z);
   }
   
   public boolean isFlying()
   {
      return flying;
   }
   
   public float getYSpeed()
   {
      return ySpeed;
   }
   
   @Override
   public boolean isInWater()
   {
      if (!mapFrameInitialized)
      {
         mapFrameInitialized = true;
         SwingUtilities.invokeLater(new Runnable()
         {
            @Override
            public void run()
            {
               new MapFrame(CustomPlayer.this, level);
               main.requestFocus();
            }
         });
      }
      
      if (Keyboard.isKeyDown(Keyboard.KEY_T))
      {
         typing = true;
      }
      
      if (Keyboard.isKeyDown(Keyboard.KEY_RETURN) || Keyboard.isKeyDown(Keyboard.KEY_ESCAPE))
      {
         typing = false;
      }
      
      if (flying)
         yd = ySpeed;
      
      if (typing)
         return super.isInWater();
         
      boolean shift = Keyboard.isKeyDown(Keyboard.KEY_LSHIFT) || Keyboard.isKeyDown(Keyboard.KEY_RSHIFT);
      boolean ctrl = Keyboard.isKeyDown(Keyboard.KEY_LCONTROL) || Keyboard.isKeyDown(Keyboard.KEY_RCONTROL);
      boolean alt = Keyboard.isKeyDown(Keyboard.KEY_LMENU) || Keyboard.isKeyDown(Keyboard.KEY_RMENU);
      
      if (Keyboard.isKeyDown(Keyboard.KEY_Q))
      {
         if (!keyFlying)
         {
            keyFlying = true;
            flying = !flying;
            
            if (flying)
               ySpeed = 0;
         }
      }
      else
      {
         keyFlying = false;
      }
      
      if (flying)
      {
         if (Keyboard.isKeyDown(Keyboard.KEY_SPACE))
         {
            if (!keyZero)
            {
               keyZero = true;
               ySpeed = 0;
            }
         }
         else
         {
            keyZero = false;
         }
         
         if (Keyboard.isKeyDown(Keyboard.KEY_C))
         {
            if (!keySubtract)
            {
               keySubtract = true;
               ySpeed -= shift ? 0.5 : 0.1;
            }
         }
         else
         {
            keySubtract = false;
         }
         
         if (Keyboard.isKeyDown(Keyboard.KEY_E))
         {
            if (!keyAdd)
            {
               keyAdd = true;
               ySpeed += shift ? 0.5 : 0.1;
            }
         }
         else
         {
            keyAdd = false;
         }
      }
      
      if (ctrl)
      {
         xd = zd = 0;
      }
      
      if (Keyboard.isKeyDown(Keyboard.KEY_ADD) || Keyboard.isKeyDown(Keyboard.KEY_EQUALS))
      {
         if (!keyTilePlus)
         {
            keyTilePlus = true;
            tileType = tileType.getNext();
         }
      }
      else
      {
         keyTilePlus = false;
      }
      
      if (Keyboard.isKeyDown(Keyboard.KEY_SUBTRACT) || Keyboard.isKeyDown(Keyboard.KEY_MINUS))
      {
         if (!keyTileMinus)
         {
            keyTileMinus = true;
            tileType = tileType.getPrevious();
         }
      }
      else
      {
         keyTileMinus = false;
      }
      
      if (Keyboard.isKeyDown(Keyboard.KEY_X))
      {
         if (!keyConjure)
         {
            keyConjure = true;
   
            int conjureX = (int)x;
            int conjureY = (int)y;
            int conjureZ = (int)z;
            
            if (ctrl)
               conjureY -= 2;
            else if (alt)
               conjureY++;
            else if (!shift)
               conjureY--;
            
            setTile(conjureX, conjureY, conjureZ, tileType.ordinal());
         }
      }
      else
      {
         keyConjure = false;
      }
      
      if (Keyboard.isKeyDown(Keyboard.KEY_Z))
      {
         if (!keyReplace)
         {
            keyReplace = true;
   
            int conjureX = (int)x;
            int conjureY = (int)y;
            int conjureZ = (int)z;
            int heading = (int)yRot % 360;
            
            if (ctrl)
               conjureY -= 2;
            else if (alt)
               conjureY++;
            else if (!shift)
               conjureY--;
            
            if (heading < 0)
               heading += 360;
         
            if (heading >= 315 || heading < 45)
               conjureZ--;
            else if (heading >= 45 && heading < 135)
               conjureX++;
            else if (heading >= 135 && heading < 225)
               conjureZ++;
            else
               conjureX--;
   
            setTile(conjureX, conjureY, conjureZ, tileType.ordinal());
         }
      }
      else
      {
         keyReplace = false;
      }
      
      if (shift)
      {
         if (Math.abs(xd) < MAX_SPEED && Math.abs(zd) < MAX_SPEED)
         {
            xd *= 2;
            zd *= 2;
         }
      }

      return super.isInWater();
   }
   
   private void setTile(int x, int y, int z, int type)
   {
      level.netSetTile(x, y, z, type);
   }
   
   public TileType getTileType()
   {
      return tileType;
   }
   
   Level getLevel()
   {
      return level;
   }
}
