// Minecraft Standalone Client
// Copyright (C) 2009-2010 Colin Bartolome
// Licensed under the GPL. See LICENSE.txt for details.

import java.awt.Color;

public enum TileType
{
   AIR(new Color(192, 255, 255)),
   DARK_GRAY(Color.DARK_GRAY),
   GRASSY_SOIL(Color.GREEN),
   SOIL(new Color(128, 64, 0)),
   GRANITE(Color.DARK_GRAY.darker()),
   BOARDS(new Color(255, 128, 64)),
   TREE(new Color(0, 128, 0)),
   ADMIN(Color.BLACK),
   INFINITE_WATER(Color.BLUE),
   FINITE_WATER(Color.BLUE),
   INFINITE_LAVA(new Color(255, 96, 0)),
   FINITE_LAVA(new Color(255, 96, 0)),
   SAND(new Color(180, 180, 100)),
   GRAVEL(Color.GRAY),
   GOLD_ORE(Color.ORANGE),
   COPPER_ORE(new Color(208, 96, 0)),
   COAL_SEAM(Color.DARK_GRAY),
   TRUNK(new Color(255, 128, 64)),
   LEAVES(Color.GREEN.darker()),
   SPONGE(Color.YELLOW),
   GLASS,
   RED(Color.RED),
   ORANGE(Color.ORANGE),
   YELLOW(Color.YELLOW),
   GREEN1(Color.GREEN.darker()),
   GREEN2(Color.GREEN),
   GREEN3(Color.GREEN.brighter()),
   BLUE1(Color.BLUE.darker()),
   BLUE2(Color.BLUE),
   BLUE3(Color.BLUE.brighter()),
   PURPLE1(new Color(128, 0, 255).darker()),
   PURPLE2(new Color(128, 0, 255)),
   PURPLE3(new Color(128, 0, 255).brighter()),
   MAGENTA(Color.MAGENTA),
   GRAY(Color.GRAY),
   LIGHT_GRAY(Color.LIGHT_GRAY),
   WHITE(Color.WHITE),
   YELLOW_FLOWER(new Color(192, 255, 0)),
   RED_FLOWER(new Color(255, 192, 0)),
   BROWN_MUSHROOM(new Color(128, 96, 0)),
   RED_MUSHROOM(new Color(255, 96, 0)),
   GOLD_BLOCK(Color.YELLOW.darker()),
   SILVER_BLOCK(new Color(192, 192, 192)),
   DOUBLE_HALF_BLOCK(Color.GRAY),
   SINGLE_HALF_BLOCK(Color.GRAY),
   BRICK(Color.RED.darker()),
   TNT(Color.RED),
   BOOKSHELF(new Color(255, 128, 64)),
   IVY_STONE(Color.GREEN),
   OBSIDIAN(new Color(92, 0, 128)),
   ;
   
   private Color color;
   
   private TileType()
   {
      this(Color.WHITE);
   }
   
   private TileType(Color color)
   {
      this.color = color;
   }
   
   @Override
   public String toString()
   {
      return name().replaceAll("_", " ").toLowerCase();
   }
   
   public TileType getNext()
   {
      TileType[] values = values();
      int ordinal = ordinal();
      
      ordinal++;
      
      if (ordinal >= values.length)
         ordinal = 0;            
      
      return values[ordinal];
   }
   
   public TileType getPrevious()
   {
      TileType[] values = values();
      int ordinal = ordinal();
      
      ordinal--;
      
      if (ordinal < 0)
         ordinal = values.length - 1;            
      
      return values[ordinal];
   }
   
   public Color getColor()
   {
      return color;
   }
}
